@@ -413,6 +413,7 @@ def newOutCallback(pin, val, pin_type):
         print "Pin " + str(pin) + " is bigger than highest pin in simulator (" + str(size) + ". Ignoring pin update"
     else:
         global win
+#        print "PYTHON: val=" + str(val)
         win.anas[pin].updateGenericPin(val, pin_type)
 
 def newLogCallback(level, text):
@@ -443,7 +444,7 @@ def newLogCallback(level, text):
         try:
             time.sleep(0.001)
             iter2 = win.textbuffer.get_end_iter()
-w            win.textbuffer.insert(iter2, text)
+            win.textbuffer.insert(iter2, text)
             time.sleep(0.001)
         except Error:
             print "Error caught"
